summaryrefslogtreecommitdiff
path: root/libavcodec/hpeldsp.h
diff options
context:
space:
mode:
authorMichael Niedermayer <michaelni@gmx.at>2013-04-20 09:40:02 +0200
committerMichael Niedermayer <michaelni@gmx.at>2013-04-20 09:42:07 +0200
commit23de9e91df1c855a89a468ee7cf203dcf0bab41f (patch)
tree19b8bf9f44dd79385270e7f43a92b1c81207f607 /libavcodec/hpeldsp.h
parent6c9d28a2294de86519c7c613c76394c66dcfd83c (diff)
parent68d8238cca52e50e8cc81bf2edcaf8088c52d4c0 (diff)
Merge commit '68d8238cca52e50e8cc81bf2edcaf8088c52d4c0'
* commit '68d8238cca52e50e8cc81bf2edcaf8088c52d4c0': hpeldsp: Add half-pel functions (currently copies of dsputil) Conflicts: libavcodec/hpeldsp.c libavcodec/hpeldsp.h libavcodec/hpeldsp_template.c Merged-by: Michael Niedermayer <michaelni@gmx.at>
Diffstat (limited to 'libavcodec/hpeldsp.h')
-rw-r--r--libavcodec/hpeldsp.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/libavcodec/hpeldsp.h b/libavcodec/hpeldsp.h
index 57a4cc1a9f..a6a2ff0e41 100644
--- a/libavcodec/hpeldsp.h
+++ b/libavcodec/hpeldsp.h
@@ -32,9 +32,12 @@
#include <stddef.h>
/* add and put pixel (decoding) */
// blocksizes for op_pixels_func are 8x4,8x8 16x8 16x16
// h for op_pixels_func is limited to {width/2, width} but never larger
// than 16 and never smaller than 4
+typedef void (*hpel_pixels_func)(uint8_t *block /*align width (8 or 16)*/,
+ const uint8_t *pixels /*align 1*/,
+ ptrdiff_t line_size, int h);
typedef void (*op_pixels_func)(uint8_t *block /*align width (8 or 16)*/,
const uint8_t *pixels /*align 1*/,
ptrdiff_t line_size, int h);
@@ -53,7 +56,7 @@ typedef struct HpelDSPContext {
* @param line_size number of bytes in a horizontal line of block
* @param h height
*/
- op_pixels_func put_pixels_tab[4][4];
+ hpel_pixels_func put_pixels_tab[4][4];
/**
* Halfpel motion compensation with rounding (a+b+1)>>1.
@@ -65,7 +68,7 @@ typedef struct HpelDSPContext {
* @param line_size number of bytes in a horizontal line of block
* @param h height
*/
- op_pixels_func avg_pixels_tab[4][4];
+ hpel_pixels_func avg_pixels_tab[4][4];
/**
* Halfpel motion compensation with no rounding (a+b)>>1.
@@ -77,7 +80,7 @@ typedef struct HpelDSPContext {
* @param line_size number of bytes in a horizontal line of block
* @param h height
*/
- op_pixels_func put_no_rnd_pixels_tab[4][4];
+ hpel_pixels_func put_no_rnd_pixels_tab[4][4];
/**
* Halfpel motion compensation with no rounding (a+b)>>1.
@@ -89,10 +92,10 @@ typedef struct HpelDSPContext {
* @param line_size number of bytes in a horizontal line of block
* @param h height
*/
- op_pixels_func avg_no_rnd_pixels_tab[4];
+ hpel_pixels_func avg_no_rnd_pixels_tab[4];
} HpelDSPContext;
-void ff_hpeldsp_init(HpelDSPContext* p, int flags);
+void ff_hpeldsp_init(HpelDSPContext *c, int flags);
void ff_hpeldsp_init_alpha(HpelDSPContext* c, int flags);
void ff_hpeldsp_init_arm(HpelDSPContext* c, int flags);
@@ -32,9 +32,12 @@
#include <stddef.h>
/* add and put pixel (decoding) */
-// blocksizes for op_pixels_func are 8x4,8x8 16x8 16x16
-// h for op_pixels_func is limited to {width/2, width} but never larger
+// blocksizes for hpel_pixels_func are 8x4,8x8 16x8 16x16
+// h for hpel_pixels_func is limited to {width/2, width} but never larger
// than 16 and never smaller than 4